<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Nepodařilo se najít žádný takový soubor nebo adresář</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Není dostupný žádný výstupní proud</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Proud je již otevřen</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Neznámá chyba:</translation>
    </message>
    <message>
        <source>Unknown RDHpiPlayStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Soubor nelze vytvořit/otevřít</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Vstupní proud je nedostupný</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Proud je již otevřen</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Neznámá chyba:</translation>
    </message>
    <message>
        <source>Unknown RDHpiRecordStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Vstupní proud</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Výstupní proud</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Vstupní přípojka</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Výstupní přípojka</translation>
    </message>
</context>
</TS>
